## Map studied TCGA cancer samples (Sepsis and SS studies) into viral infected samples detected in Cao et al., 2016
## Perform Infected pathway enrichment analysis

## Infected samples data
library(tcnibmg)
data(tc.eset)
load("../Metadata/gbyp.rda")

## Infected samples data
#cao_data = read.table(file="/home/bigdata/Dropbox/Manuscript.2019/analysis/Metadata/Cao_2016.csv", 
#                      header = T, row.names = 1)
cao_data = read.table(file="../Metadata/Cao_2016.csv", header = T, row.names = 1)
cao_smp_name = substr(rownames(cao_data),1,15)
cao_smp_name = gsub("-",".", cao_smp_name)

## Sample matching for LIHC
tcga_smp_name = substr(sampleNames(tc.eset$LIHC), 1,15)
cao_smp_name.ind =  which(cao_smp_name %in% tcga_smp_name)
caoinsmp = cao_data[cao_smp_name.ind,]
caoinsmp$AllColMax <- apply(caoinsmp[,2:dim(caoinsmp)[2]], 1, function(x) max(x))
tcga_smp_mapped = subset(caoinsmp,caoinsmp$AllColMax > 100)
infected_sample = substr(rownames(tcga_smp_mapped), 1,15)
infected_sample = gsub("-",".", infected_sample)

## LIHC expression data
LIHC = exprs(tc.eset$LIHC)
eset = tc.eset$LIHC

sampleNames(eset) = substr(sampleNames(eset),1,15)
group = as.character(eset$Target)
names(group) = sampleNames(eset)
group[infected_sample] = "Infected"
group[group=="Case"] = "Uninfected"
eset$Group = factor(group)
rm(group)

xuni = rowMeans(exprs(eset[, eset$Group=="Uninfected"]))
xinf = rowMeans(exprs(eset[, eset$Group=="Infected"]))


for(pathid in inf_pathways){
  pathegs = intersect(genes.by.pathway[[pathid]], featureNames(eset))
  #xcon = as.numeric(rowMeans(exprs(eset[pathegs, eset$Group=="Normal"])))
  #xuni = as.numeric(rowMeans(exprs(eset[pathegs, eset$Group=="Uninfected"])))
  #xinf = as.numeric(rowMeans(exprs(eset[pathegs, eset$Group=="Infected"])))
  boxplot((xinf-xuni)[pathegs])
  abline(h=0)
  
  ## Expression data selected pathway
  #gset = eset[pathegs, eset$Group=="Normal"]
  
  #infected_samples_normal = gsub(".01", ".11", infected_sample)
  #which.inf.normal = which(colnames(gset)%in%infected_samples_normal)
  #which.uni.normal = which(!colnames(gset)%in%infected_samples_normal)
  #xcon.uni = as.numeric(rowMeans(exprs(gset[, which.uni.normal])))
  #xcon.inf = as.numeric(rowMeans(exprs(gset[, which.inf.normal])))
  #boxplot(list(xcon.uni, xcon.inf),names=c("Uninfected","Infected"), main=pathid)
  scan()}

## tumor samples expression
t_ind = which(substr(colnames(gexp),14,15)=="01")
t_smp = hsa04810gexp[,t_ind]

inf.ind = which(substr(colnames(t_smp),1,15) %in% infected_sample)
inf_gset = t_smp[,inf.ind]
uninf_gset = t_smp[,-inf.ind]

## Mean expression of tumor samples
inf_gset_mean = apply(inf_gset, 1, function(x) mean(x))
uninf_gset_mean = apply(uninf_gset, 1, function(x) mean(x))

## Normal samples expression 
n_ind = which(substr(colnames(hsa04810gexp),14,15)=="11")
n_smp = hsa04810gexp[,n_ind]

normal_samples_name_inf = paste0(substr(colnames(inf_gset),1,13),"11")
normal_samples_name_uninf = paste0(substr(colnames(uninf_gset),1,13),"11")
normal_samples_name_inf_ind = which(substr(colnames(n_smp),1,15) %in% normal_samples_name_inf)

normal_inf_gset = n_smp[,normal_samples_name_inf_ind]
normal_uninf_gset = n_smp[,-normal_samples_name_inf_ind]

#################### End of today




## get pathway genes
inf_pathways <- c("hsa05161", "hsa05160", "hsa05152", "hsa05146", "hsa05142",
                            "hsa05134", "hsa05133", "hsa05132", "hsa05120", "hsa05110",
                            "hsa05100", "hsa04810", "hsa04721", "hsa04668", "hsa04666",
                            "hsa04664", "hsa04622", "hsa04620", "hsa04612", "hsa04145", 
                            "hsa04670", "hsa04142")
path_ind = which(names(genes.by.pathway) %in% inf_pathways)
inf_pathways_genes = genes.by.pathway[path_ind]

out_path = list()
out_inf_es = list()
out_uninf_es = list()
 for(i in 1:length(inf_pathways_genes)){
   
   pathway_i2 = inf_pathways_genes[i]
   pathway_i = unlist(pathway_i2)
   
   ## Expression data selected pathway
   gene.ind = which(rownames(LIHC) %in% pathway_i)
   hsa04810gexp = LIHC[gene.ind,]
   
   ## tumor samples expression
   t_ind = which(substr(colnames(hsa04810gexp),14,15)=="01")
   t_smp = hsa04810gexp[,t_ind]
   
   inf.ind = which(substr(colnames(t_smp),1,15) %in% infected_sample)
   inf_gset = t_smp[,inf.ind]
   uninf_gset = t_smp[,-inf.ind]
   
   ## Mean expression of tumor samples
   inf_gset_mean = apply(inf_gset, 1, function(x) mean(x))
   uninf_gset_mean = apply(uninf_gset, 1, function(x) mean(x))
   
   ## Normal samples expression 
   n_ind = which(substr(colnames(hsa04810gexp),14,15)=="11")
   n_smp = hsa04810gexp[,n_ind]
   
   normal_samples_name_inf = paste0(substr(colnames(inf_gset),1,13),"11")
   normal_samples_name_uninf = paste0(substr(colnames(uninf_gset),1,13),"11")
   normal_samples_name_inf_ind = which(substr(colnames(n_smp),1,15) %in% normal_samples_name_inf)
   
   normal_inf_gset = n_smp[,normal_samples_name_inf_ind]
   normal_uninf_gset = n_smp[,-normal_samples_name_inf_ind]
   
   ## Mean expression of normal samples
   normal_inf_gset_mean = apply(normal_inf_gset, 1, function(x) mean(x))
   normal_uninf_gset_mean = apply(normal_uninf_gset, 1, function(x) mean(x))
   
   ## FC calculation
   fc_uninf =  uninf_gset_mean - normal_uninf_gset_mean
   fc_inf =  inf_gset_mean - normal_inf_gset_mean
   
   ## ES calculation
   fc_uninf_es =  sum(fc_uninf)/sqrt(length(fc_uninf))
   fc_inf_es =  sum(fc_inf)/sqrt(length(fc_inf))
   
   out_path[i] = names(pathway_i2)
   out_inf_es[i] = fc_inf_es
   out_uninf_es[i] = fc_uninf_es
 }

out_path = data.frame(unlist(out_path))
out_inf_es = data.frame(unlist(out_inf_es))
out_uninf_es = data.frame(unlist(out_uninf_es))

output = data.frame(out_path,out_inf_es,out_uninf_es)
colnames(output) <- c("Pathway", "Infected", "Uninfected")

print(output)
with(output, plot(Uninfected, Infected, xlim=c(0,6), ylim=c(0,6)))
with(output, t.test(Infected-Uninfected))
