## Find Age, gender from TCGA clinical data for Sepsis-Cancer analysis

library(tcnibmg)
data(tc.eset)

#cancer_type = "COAD"
#eset = tc.eset$COAD
output_pheno = list()

for (i in 1:17){
  eset = tc.eset[[i]]
  fl_nm = names(tc.eset[i])
  ## Read TCGA clinical file
  cl_file_nm = paste0("Metadata/", fl_nm, "_clinical.tsv")
  
  cl_data = read.table(file =cl_file_nm, header = T, row.names = 1,sep = "\t")
  cl_data$submitter_id <- gsub("-",".",as.character(cl_data$submitter_id))
  
  ## Tumor samples
  t_ind = which(substr(colnames(eset),14,15)=="01")
  t_smp = exprs(eset[,t_ind])
  
  ## Clinical data for selected samples
  c_ind = which(as.character(cl_data$submitter_id) %in% substr(colnames(t_smp),1,12))
  c_smp = cl_data[c_ind,]
  
  ## Average age of diagnosis 
  age_diag = subset(c_smp, c_smp$age_at_diagnosis != "--")
  avg_age_diag = mean(as.numeric(as.character(age_diag$age_at_diagnosis)))
  avg_age_diag = (avg_age_diag)/30/12
  
  ## Average gender 
  gender = subset(c_smp, c_smp$gender != "--")
  gender_mf = ifelse(as.character(c_smp$gender)=="female",1,0)
  
  gender_m = sum(gender_mf==0)/dim(c_smp)[1]
  gender_f = sum(gender_mf==1)/dim(c_smp)[1]
  
  output_pheno[[i]] = c(fl_nm, avg_age_diag, gender_m, gender_f)
  
}

output_pheno_df = do.call(rbind.data.frame, output_pheno)
colnames(output_pheno_df) <- c("Cancer","Average_age_of_diagnosis","Male_Percent","Female_percent")
output_pheno_df
