# Fig 4A
graphics.off()
par(mar=c(5,7,4,2))
barplot(percSignifSurv[ids.slc], col=mycols, ylim=c(0,59), ylab="Percentage of pathways\
        associated with survival", cex.lab = 1.5,
        main="Association of Selected Pathways with\nSurvival from Cancer in SLC group")
box()
fig4a = "Figures_for_manuscript/Fig_4A.pdf"
if(!file.exists(fig4a)) {
  dev.copy(device=pdf, file=fig4a)
  dev.off()
} else {
  print.noquote(paste0("Figure exists - ", fig4a))
}
rm(fig4a)

scan()
##########################################
# Draw representative K-M plots
# Fig 4B
##########################################
pathid = "hsa04666"
proj = c("HNSC","KIRC","LIHC")[1]
#graphics.off(); rm(sfit, dat, info, pathX, projES, to.keep, sel.ptids)
graphics.off()
# get the clinical metadata from an external file and add to the expression set
info = read.table(file=paste0("Metadata/",proj,"_surv_clinical.tsv"), header=T, sep="\t")
to.keep = (apply(info[,2:3], 1, function(x) !all(x=="--")))
info = info[to.keep,]
is.na(info) <- info=="--"

rownames(info) = gsub("-",".", info$submitter_id)

sel.ptids = intersect(rownames(info), sampleNames(pathES))
#print.noquote(length(sel.ptids))
projES = pathES[, sel.ptids]
info = info[sel.ptids,]

pathX = as.vector(exprs(projES[paste0("x.", pathid), ]))
names(pathX) = sampleNames(projES)
dat = data.frame(info, pathX)
dat$day = as.integer(as.character(dat$days_to_death))
dat$day[dat$outcome==0] = as.integer(as.character(dat$days_to_last_follow_up[dat$outcome==0]))
dat$high_expressing = as.integer(dat$pathX > median(dat$pathX))
dat = dat[!is.na(dat$day),]
#print.noquote(nrow(dat))
sfit <- survfit(Surv(day, outcome)~high_expressing, data=dat)
res = ggsurvplot(sfit, conf.int=FALSE, pval=TRUE, risk.table=TRUE, 
                 legend.labs=c("Low", "High"), 
                 legend.title=paste0(pathid, " Score"),  
                 palette=c("dodgerblue2", "orchid2"), 
                 title=paste0("Kaplan-Meier Curve for survival in ", proj, "\nusing the pathway ", pathid), 
                 risk.table.height=.25)
pval = surv_pvalue(sfit, data = NULL, method = "survdiff",
                   test.for.trend = FALSE, combine = FALSE)$pval
cat(paste0(pathid, " ", proj, " ", formatC(pval, digits=2), "\n"))
print(res)
rm(sfit, dat, info, pathX, projES, to.keep, sel.ptids)
fig4b = "Figures_for_manuscript/Fig_4B.pdf"
if(!file.exists(fig4b)) {
  dev.copy(device=pdf, file=fig4b)
  dev.off()
} else {
  print.noquote(paste0("Figure exists - ", fig4b))
}
rm(fig4b)



scan()
#################################
#          Fig 4C
#################################
proj = c("HNSC","KIRC","LIHC")[2]
#graphics.off(); rm(sfit, dat, info, pathX, projES, to.keep, sel.ptids)
graphics.off()
# get the clinical metadata from an external file and add to the expression set
info = read.table(file=paste0("Metadata/",proj,"_surv_clinical.tsv"), header=T, sep="\t")
to.keep = (apply(info[,2:3], 1, function(x) !all(x=="--")))
info = info[to.keep,]
is.na(info) <- info=="--"

rownames(info) = gsub("-",".", info$submitter_id)

sel.ptids = intersect(rownames(info), sampleNames(pathES))
#print.noquote(length(sel.ptids))
projES = pathES[, sel.ptids]
info = info[sel.ptids,]

pathX = as.vector(exprs(projES[paste0("x.", pathid), ]))
names(pathX) = sampleNames(projES)
dat = data.frame(info, pathX)
dat$day = as.integer(as.character(dat$days_to_death))
dat$day[dat$outcome==0] = as.integer(as.character(dat$days_to_last_follow_up[dat$outcome==0]))
dat$high_expressing = as.integer(dat$pathX > median(dat$pathX))
dat = dat[!is.na(dat$day),]
#print.noquote(nrow(dat))
sfit <- survfit(Surv(day, outcome)~high_expressing, data=dat)
res = ggsurvplot(sfit, conf.int=FALSE, pval=TRUE, risk.table=TRUE, 
                 legend.labs=c("Low", "High"), 
                 legend.title=paste0(pathid, " Score"),  
                 palette=c("dodgerblue2", "orchid2"), 
                 title=paste0("Kaplan-Meier Curve for survival in ", proj, "\nusing the pathway ", pathid), 
                 risk.table.height=.25)
pval = surv_pvalue(sfit, data = NULL, method = "survdiff",
                   test.for.trend = FALSE, combine = FALSE)$pval
cat(paste0(pathid, " ", proj, " ", formatC(pval, digits=2), "\n"))
print(res)
rm(sfit, dat, info, pathX, projES, to.keep, sel.ptids)
fig4c = "Figures_for_manuscript/Fig_4C.pdf"
if(!file.exists(fig4c)) {
  dev.copy(device=pdf, file=fig4c)
  dev.off()
} else {
  print.noquote(paste0("Figure exists - ", fig4c))
}
rm(fig4c)

scan()
#################################
#          Fig 4D
#################################
proj = c("HNSC","KIRC","LIHC")[3]
#graphics.off(); rm(sfit, dat, info, pathX, projES, to.keep, sel.ptids)
graphics.off()
# get the clinical metadata from an external file and add to the expression set
info = read.table(file=paste0("Metadata/",proj,"_surv_clinical.tsv"), header=T, sep="\t")
to.keep = (apply(info[,2:3], 1, function(x) !all(x=="--")))
info = info[to.keep,]
is.na(info) <- info=="--"

rownames(info) = gsub("-",".", info$submitter_id)

sel.ptids = intersect(rownames(info), sampleNames(pathES))
#print.noquote(length(sel.ptids))
projES = pathES[, sel.ptids]
info = info[sel.ptids,]

pathX = as.vector(exprs(projES[paste0("x.", pathid), ]))
names(pathX) = sampleNames(projES)
dat = data.frame(info, pathX)
dat$day = as.integer(as.character(dat$days_to_death))
dat$day[dat$outcome==0] = as.integer(as.character(dat$days_to_last_follow_up[dat$outcome==0]))
dat$high_expressing = as.integer(dat$pathX > median(dat$pathX))
dat = dat[!is.na(dat$day),]
#print.noquote(nrow(dat))
sfit <- survfit(Surv(day, outcome)~high_expressing, data=dat)
res = ggsurvplot(sfit, conf.int=FALSE, pval=TRUE, risk.table=TRUE, 
                 legend.labs=c("Low", "High"), 
                 legend.title=paste0(pathid, " Score"),  
                 palette=c("dodgerblue2", "orchid2"), 
                 title=paste0("Kaplan-Meier Curve for survival in ", proj, "\nusing the pathway ", pathid), 
                 risk.table.height=.25)
pval = surv_pvalue(sfit, data = NULL, method = "survdiff",
                   test.for.trend = FALSE, combine = FALSE)$pval
cat(paste0(pathid, " ", proj, " ", formatC(pval, digits=2), "\n"))
print(res)
rm(sfit, dat, info, pathX, projES, to.keep, sel.ptids)
fig4d = "Figures_for_manuscript/Fig_4D.pdf"
if(!file.exists(fig4d)) {
  dev.copy(device=pdf, file=fig4d)
  dev.off()
} else {
  print.noquote(paste0("Figure exists - ", fig4d))
}
rm(fig4d)