# Given an expression set of TCGA project, returns the normalized expression set
# with log(tumour FPKM) - log(adj normal FPKM)
# as an expression set
makeNormEsetTCGA = function(eset) {
  # get the sample names 
  snames = sampleNames(eset)
  # get the case/control status
  eset$casecon = c("Case","Normal")[1+as.integer(substr(snames,14,14)==1)]
  # get the subject id
  eset$ptid = substr(snames, 1, 12)

  # remove samples that are not paired
  ptids.single = names(which(table(eset$ptid)==1))
  sel = !(eset$ptid%in%ptids.single)
  esetp = eset[,sel]

  # For each pt id, calculate log-fold change in expression: log(tumor FPKM) - log(adj normal FPKM)
  # This forms the assay data of new expression set
  unids = unique(esetp$ptid)
  gexp = sapply(unids, function(id) {
    which.con = which(esetp$ptid==id & esetp$casecon=="Normal")
    which.case = which(esetp$ptid==id & esetp$casecon=="Case")
    xcon = exprs(esetp[,which.con])
    xcase = exprs(esetp[,which.case])
    x = xcase-xcon
    return(x)
  })
  rownames(gexp) = featureNames(esetp)
  
  # pheno data
  metadata = data.frame(as.matrix(unids))
  colnames(metadata) = "ID"
  
  pData = AnnotatedDataFrame(data.frame(unids))
  sampleNames(pData) = metadata$ID
  
  esetn <- new("ExpressionSet", exprs = gexp,
                  phenoData = pData, 
                  experimentData = experimentData(esetp),
                  annotation = annotation(esetp))
  
  # return the rowttests output
  return(esetn)
}