# Given an expression set of TCGA project, returns the normalized expression set
# with Z score formula z = [(value gene X in tumor Y)-(mean gene X in normal)]/(standard deviation X in normal)]
# as an expression set
makeNormEsetTCGAusingZscore = function(eset) {
  # get the sample names 
  snames = sampleNames(eset)
  # get the case/control status
  eset$casecon = c("Case","Normal")[1+as.integer(substr(snames,14,14)==1)]
  # get the subject id
  eset$ptid = substr(snames, 1, 12)

  # remove samples that are not paired
  ptids.single = names(which(table(eset$ptid)==1))
  sel = !(eset$ptid%in%ptids.single)
  esetp = eset[,sel]

 
  
  n_index <- which(substr(sampleNames(esetp),14,14) == '1')
  t_index <- which(substr(sampleNames(esetp),14,14) == '0')
  
  # calculate z-scores
  # This forms the assay data of new expression set

  scal <- function(x,y){
    mean_n <- rowMeans(y)  # mean of normal
    sd_n <- apply(y,1,sd)  # SD of normal
    # z score as (value - mean normal)/SD normal
    res <- matrix(nrow=nrow(x), ncol=ncol(x))
    colnames(res) <- colnames(x)
    rownames(res) <- rownames(x)
    for(i in 1:dim(x)[1]){
      for(j in 1:dim(x)[2]){
        res[i,j] <- (x[i,j]-mean_n[i])/sd_n[i]
      }
    }
    return(res)
  }
  
  gexp <- scal(exprs(esetp)[,t_index],exprs(esetp)[,n_index])
  colnames(gexp) <- substr(colnames(gexp),1,12)
  
  
  unids = unique(esetp$ptid)
  
  # pheno data
  metadata = data.frame(as.matrix(unids))
  colnames(metadata) = "ID"
  
  pData = AnnotatedDataFrame(data.frame(unids))
  sampleNames(pData) = metadata$ID
  
  esetn <- new("ExpressionSet", exprs = gexp,
                  phenoData = pData, 
                  experimentData = experimentData(esetp),
                  annotation = annotation(esetp))
  
  # return the rowttests output
  return(esetn)
}
