mysurvplot = function(egid="", pathid="hsa05414", usingPathway=FALSE, eset=brcan, projid="BRCA") {
  if(!usingPathway) {
    # get the gene expression data for the gene
    x = exprs(brcan[egid,])
  } else {
    pathstr = pathways.list[[paste0("path:",pathid)]]
    pathstr = strsplit(pathstr, split="\\ -")[[1]][1]
    egs = genes.by.pathway[[pathid]]
    egs = intersect(egs, featureNames(eset))
    x = colMeans(exprs(eset[egs,]))
  }
  
  # label samples and up or down, based on a cutoff on zero
  cutoff = median(x)
  if(cutoff>0) {
    gstat = as.integer(x>cutoff)
  } else {
    gstat = as.integer(x<cutoff)
  }
  
  # get days to death and outcome
  is.dead = eset$outcome==1
  days = rep(NA, ncol(eset))
  days[is.dead] = as.integer(as.character(eset$days_to_death[is.dead]))
  
  days[!is.dead] = as.integer(as.character(eset$days_to_last_follow_up[!is.dead]))
  outcome = eset$outcome
  my.surv = Surv(time=days,event=outcome)
  survival_diff <- survdiff(my.surv~gstat)
  p.value = 1-pchisq(survival_diff$chisq, df=1)
  my.fit = survfit(my.surv~gstat)
  par(mar=c(4,4,4,4))
  plot(my.fit, col=c("darkgreen","red"), lwd=3, 
       xlab="Days", ylab="Survival (percent)", 
       main=paste0("Survival analysis for ",projid, " with ", 
                   ifelse(usingPathway, paste0(pathid, " | ", pathstr), egid)),
       yscale=100)
  legend(legend=paste0("p = ", formatC(p.value, digits=1)), 
         x="topright", bty="n", col="blue")
  
  return(survival_diff)
}