mysurvplotusingZscore = function(egid="", pathid="hsa05414", usingPathway=FALSE, eset=brcan, proj="BRCA") {
  if(!usingPathway) {
    # get the gene expression data for the gene
    x = exprs(brcan[egid,])
  } else {
    pathstr = pathways.list[[paste0("path:",pathid)]]
    pathstr = strsplit(pathstr, split="\\ -")[[1]][1]
    egs = genes.by.pathway[[pathid]]
    egs = intersect(egs, featureNames(eset))
    x = colMeans(exprs(eset[egs,]))
  }
  
  # label samples and up or down, based on a cutoff on zero 1=up; 0=down
  #cutoff <- 1.96
  colnames(x) <- gsub('\\.','-',substr(colnames(x),1,12))
  gstat = t(apply(x, 1, function(x) ifelse(x > 1.96,1,ifelse(x < -1.96,0,2))))
  gstat.sel = which(!(gstat[1,]==2))
  gstat = gstat[,gstat.sel]
  
  eset_cli_raw = pData(eset)
  ## Remove minus entries in days_to_last_follow_up
  neg_vals = length(which(as.numeric(as.character(eset_cli_raw$days_to_last_follow_up)) < 0))
  if (neg_vals > 0){
    neg_vals_pos = which(as.numeric(as.character(eset_cli_raw$days_to_last_follow_up)) < 0)
    eset_cli = eset_cli_raw[-neg_vals_pos,]
  } else {
    eset_cli = eset_cli_raw
  }
  gstat_in_clin = which(names(gstat) %in% eset_cli$submitter_id)
  gstat = gstat[gstat_in_clin]
  
  if (dim(table(gstat)) == 1 | dim(table(gstat)) == 0){
    cat("Only single group data is provided ...")
    #cat(" done!\n")
    #return(egid)
  } else {
    is.dead.trim = eset_cli$submitter_id %in% names(gstat)
    trim_cli = eset_cli[is.dead.trim,] 
    is.dead = trim_cli$outcome==1
    days = rep(NA, dim(trim_cli)[1])

    days[is.dead] = as.integer(as.character(trim_cli$days_to_death[is.dead]))
    days[!is.dead] = as.integer(as.character(trim_cli$days_to_last_follow_up[!is.dead]))
    
    outcome = trim_cli$outcome
    my.surv = Surv(time=days,event=outcome)
    my.fit = survfit(my.surv~gstat)
    survival_diff <- survdiff(my.surv~gstat)
    chipval  = abs(pchisq((survival_diff$chisq), df=1, log.p=T))
 
    # Plot only significant survial data   
#    if (chipval > 0.05){
#      cat("Not significant ...")
#      return(egid)
#    } else {
      #chipval = chipval
      #return(egid)
#      plot(my.fit, col=c("darkgreen","red"), lwd=3, 
#           xlab="Days", ylab="Survival (percent)", 
#           main=paste0("Survival analysis for ",proj, " with ", 
#                       ifelse(usingPathway, paste0(pathid, " | ", pathstr), egid)), yscale=100) 
#    }
#    dev.off()
    return(survival_diff)
    
  }
}

  