require(KEGG.db)
require("latticeExtra")
require("lattice")

# defining a function which takes the pathway ids as input and a levelplot is drawn 
plotOverlap <- function(p.codes=p.codes, p.names=NULL){
    
    overlapIndex = getOverlap(p.codes=p.codes) # calling the getOverlap function to get the overlap matrix
    dd.row=as.dendrogram(hclust(dist(overlapIndex))) # hierarchial clustering to get how the rows are clustering 
    row.ord=order.dendrogram(dd.row)
    lp = levelplot(t(overlapIndex)[row.ord,row.ord], pretty=FALSE,
                   scales=list(x=list(rot=90)), xlab="", main ="overlapIndex",
                   ylab="",col.regions=colorRampPalette(c("white", "darkblue"))(256))
    plot(lp)
}

##defining a function to obtain the overlap of genes between each of the pathways
getOverlap  <- function(p.codes=p.codes , p.names=NULL){ #taking pathway ids as input and pathway names as an optional input
    
    genes.by.pathway.codes <- genes.by.pathway[p.codes] # creating a gene by pathway list of the given pathway ids	
    
    ## checking if there is input for pathway names 
    # if not generate a character vector of pathway names
    # from the KEGG.db using pathway ids as keys 
    
    if(is.null(p.names)){ 
        p.ids <- sapply(p.codes, function(x){
            y=strsplit(x, split = "a", fixed = TRUE)
            y[[1]][2]
        })
        p.names <- unlist(mget(p.ids, KEGGPATHID2NAME,ifnotfound =NA))
    }
    # ensuring that pathway names and pathway ids vector are equal in length
    if(length(p.codes)!=length(p.names)){
        stop("Length of pathway codes and pathway names are different." , call. = TRUE)
    }
    
    # creating a gene by pathway list of the pathway names
    
    genes.by.pathway.names <- genes.by.pathway.codes
    names(genes.by.pathway.names) <- p.names
    
    ## using nested sapply to generate a intersection matrix of genes in each of the pathways 
    
    intersect.mat <- sapply(genes.by.pathway.codes,function(x){
        sapply(genes.by.pathway.names, function(y){
            length(intersect(x,y))/length(union(x,y))
        })
        
    })
    
    return(intersect.mat)
}
