############################################################################################################
# Network analysis
# Fig:
############################################################################################################
# get a network of KEGG pathways (with size > 10)
which.large = sapply(genes.by.pathway, length)>10
ids = names(genes.by.pathway[which.large])

# make the pathway names shorter
shortids = sapply(strsplit(ids, split="hsa"), "[[", 2)
shortids = as.character(as.integer(shortids))
names(shortids) = ids

# net info
keggpairs = t(combn(shortids,2))
overlap = c()
for(i in 1:nrow(keggpairs)) {
  id1 = names(which(shortids==keggpairs[i,1]))
  id2 = names(which(shortids==keggpairs[i,2]))
  genes1 = genes.by.pathway[[id1]]
  genes2 = genes.by.pathway[[id2]]
  common = intersect(genes1, genes2)
  both = union(genes1, genes2)
  overlap[i] = length(common)/length(both)
}
netdat = data.frame(keggpairs, overlap)
colnames(netdat) = c("from","to","Overlap")

# keep those kegg pairs with overlap above a threshold (5%)
overlap.threshold = 0.05
links = netdat[netdat[,3]>overlap.threshold,]
nodes = unique(as.character(unlist(links[,1:2])))


# create a graph object
require(igraph)
g <- graph_from_data_frame(d=links, vertices=nodes, directed=F)
# plot(g, vertex.label.color="black", vertex.label.dist=1, vertex.size=7)
E(g)$width = links[,3]

# Identify vertices with coresness <= threshold
toosmall <- which(graph.coreness(g) <= 2)
# Delete vertices and plot
gp <- delete.vertices(g, toosmall)

rm(ids, id1, id2, genes1, genes2, common, both, overlap, netdat, overlap.threshold, links, nodes, toosmall)

graphics.off()
deg_dist_gp <- degree_distribution(gp, cumulative = TRUE)
plot(deg_dist_gp, xlab="Degree", ylab="Cumulative Frequency", pch=16, cex=0.86, main="Degree distribution of \n KEGG pathway overlap network")
cat("Degree distribution of the nodes in the KEGG network: ")
scan()

# color the nodes on the network
sel.nodes = c(pathways.c.only, pathways.sl.only, pathways.both)

nodes.66 = shortids[sel.nodes]

nodenames = vertex_attr(gp)$name
mycolors = rep("gray90",length(nodenames))
names(mycolors) = nodenames

mycolors[nodenames%in%nodes.66] = "red"
# resize the vertex size
node.size <- rep(4, length(V(gp)))

V(gp)$color = mycolors

# layout
coords = layout_(gp, nicely())

#par(pty="s")
opar = par()
par(mar=c(1,1,1,1))
plot(gp, layout=coords, vertex.label.color=V(gp)$color, vertex.label.dist=1, vertex.label=NA,
     vertex.label.cex=0.8, vertex.label.dist=1, 
     vertex.size= node.size, vertex.frame.color=0, edge.curved=0.5)
par(opar)

#tkid <- tkplot(gp) #tkid is the id of the tkplot that will open
#l <- tkplot.getcoords(tkid) # grab the coordinates from tkplot
#plot(net, layout=l)

#rm(all.node.dat, sel.node.dat, keggnames, node.size, mycolors, nodenames, shortids, g, gp, i)
cat("Selected pathways are at the core of the network!")



#################################################################
## Barplot of degree. Red plo
dg = degree(gp)
dg = dg[order(dg)]

sel.nodes = c(pathways.c.only, pathways.sl.only, pathways.both)
nodes.66 = shortids[sel.nodes]
nodenames = vertex_attr(gp)$name
mycolors = rep("gray90",length(dg))
names(mycolors) = names(dg)

mycolors[names(dg)%in%nodes.66] = "red"

barplot(dg,cex.names = 0.5,col=mycolors,xlab = "Pathway",ylab = "Frequency")


##########################################################
###Gene expression and heatmap
ct_exp = exprs(tc.eset$BLCA)
ct_exp_ph = tc.eset$BLCA$Target

st_exp = exprs(ss.eset$GSE13904)
st_exp_ph = ss.eset$GSE13904$Group


require(genefilter)
rtt = rowttests(as.matrix(st_exp),st_exp_ph)   




padj = p.adjust(rtt$p.value,method='BH')
rtt$padj<-padj