## Prepare data for machine learning (SVM, NN)  analysis 
## (Samplewise tumor-normal data) 
## Each sample has 66 pathway scores
##
## First run code in main.R up to 
# ...
# source("Rcode/drawPathwayHeatmap.R")
# before calling this script
#################################################

# Get pathway expression data for selected 66 pathways
pathids = sel

# Function to get normalixed gene expression matrix
# for a given expression set
getSampleGexp = function(eset) {
  # use all samples with "A" label (exclude B, C, etc.)
  to.keep = which((substr(colnames(eset),16,16))=="A")
  eset = eset[,to.keep]
  # get sample id
  all.ids = substr(colnames(eset),1,12)
  smpl.ids = which(table(all.ids)==2) %>% names
  t.id = paste0(smpl.ids, ".01A_mR")
  n.id = paste0(smpl.ids, ".11A_mR")
  gexp = exprs(eset[,t.id]) - exprs(eset[,n.id])
  colnames(gexp) = smpl.ids
  return(gexp)
}
# Get normalized gene expression for each case
list.gexp = sapply(tc.eset, getSampleGexp)

# Function to get pathway score (zobs) given a pathway id and 
# a gene expression matrix
getPathScore = function(pathid=pathid, gexp) {
  curr.egs = intersect(genes.by.pathway[[pathid]], rownames(gexp))
  x = gexp[curr.egs,]
  apply(x, 2, function(y) {
    y = sum(y)/sqrt(length(y))
  })
}

# Function to get the pathway expression matrix for a gene expression matrix
getZobs = function(gexp) {
  sapply(pathids, function(pathid) {
    getPathScore(pathid, gexp)
  }) %>% t  
}

# get a list of pathway score matrix for all studies
list.zobs = sapply(list.gexp, getZobs)

# Format data for classification
# Transpose data such that each row is a subject
list.zobs.trans = sapply(list.zobs, t)
list.input.slc = list.zobs.trans[ids.sepsis.like]
list.input.ca = list.zobs.trans[ids.cancer]

# format data into a single matrix
# first, create the matrix for SLC
id = ids.sepsis.like[1]
nsamples = nrow(list.input.slc[[id]])
tissue = rep(id, nsamples)
label = rep("SLC", nsamples)
x = data.frame(x = list.input.slc[[id]], Tissue = tissue, label = label)

for(i in 2:length(ids.sepsis.like)) {
  id = ids.sepsis.like[i]
  nsamples = nrow(list.input.slc[[id]])
  tissue = rep(id, nsamples)
  label = rep("SLC", nsamples)
  x = rbind(x, data.frame(x = list.input.slc[[id]], Tissue = tissue, label = label))
}

# add the CA samples
for(i in 1:length(ids.cancer)) {
  id = ids.cancer[i]
  nsamples = nrow(list.input.ca[[id]])
  tissue = rep(id, nsamples)
  label = rep("CA", nsamples)
  x = rbind(x, data.frame(x = list.input.ca[[id]], Tissue = tissue, label = label))
}

# make an expression set
assaydata = t(x[,1:66])
phenodata = new("AnnotatedDataFrame", x[,67:68])
pathES = new("ExpressionSet", exprs=assaydata, phenoData=phenodata)

